pub struct ActionAuditTrailAspect { /* private fields */ }Expand description
Audit-trail aspect.
The host calls bind(ctx) before each guarded invocation. The
aspect appends one record per invocation, in arrival order.
Implementations
Sourceimpl ActionAuditTrailAspect
impl ActionAuditTrailAspect
Sourcepub fn bind(&self, ctx: AuditContext) -> u64
pub fn bind(&self, ctx: AuditContext) -> u64
Bind an audit context to the next guarded invocation.
Sourcepub fn snapshot(&self) -> Vec<AuditRecord>
pub fn snapshot(&self) -> Vec<AuditRecord>
Snapshot the full audit trail.