RateLimitAspect

Struct RateLimitAspect 

pub struct RateLimitAspect { /* private fields */ }
Rate limiting aspect with token bucket algorithm.

Limits the rate at which functions can be called, useful for API throttling, resource protection, and preventing abuse.

Example

use aspect_std::RateLimitAspect;
use aspect_macros::aspect;
use std::time::Duration;

// Allow 10 calls per second
let limiter = RateLimitAspect::new(10, Duration::from_secs(1));

#[aspect(limiter.clone())]
fn api_call(data: String) -> Result<(), String> {
    // This function is rate-limited
    Ok(())
}

Implementations

Source

impl RateLimitAspect

pub fn new(max_requests: u64, window: Duration) -> Self

Create a new rate limiter.

Arguments
  • max_requests - Maximum number of requests allowed
  • window - Time window for the limit
Example
// 100 requests per minute
let limiter = RateLimitAspect::new(100, Duration::from_secs(60));
pub fn per_function(self) -> Self

Enable per-function rate limiting.

When enabled, each function gets its own token bucket.

pub fn available_tokens(&self) -> f64

Get current token count.